@@ -3,10 +3,9 @@
 
 import time
 import board
-import busio
 import adafruit_veml7700
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
 veml7700 = adafruit_veml7700.VEML7700(i2c)
 
 while True:
